@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -39,7 +39,7 @@ class ContactConfigureDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit ContactConfigureDialog(QWidget *parent = Q_NULLPTR);
+    explicit ContactConfigureDialog(QWidget *parent = nullptr);
     ~ContactConfigureDialog();
 
     void readConfig();
