@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,7 +25,7 @@ class PreviewWidget : public GrantleeThemeEditor::PreviewWidget
 {
     Q_OBJECT
 public:
-    explicit PreviewWidget(const QString &projectDirectory, QWidget *parent = Q_NULLPTR);
+    explicit PreviewWidget(const QString &projectDirectory, QWidget *parent = nullptr);
     ~PreviewWidget();
 
     void createScreenShot(const QStringList &fileList) Q_DECL_OVERRIDE;
