@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -37,8 +37,8 @@ class GrantleeThemeEditor::ManageThemesPrivate
 {
 public:
     ManageThemesPrivate()
-        : mListThemes(Q_NULLPTR),
-          mDeleteTheme(Q_NULLPTR)
+        : mListThemes(nullptr),
+          mDeleteTheme(nullptr)
     {
 
     }
@@ -108,7 +108,7 @@ void ManageThemes::writeConfig()
 
 void ManageThemes::slotDeleteTheme()
 {
-    QList<QListWidgetItem *> selectItems = d->mListThemes->selectedItems();
+    const QList<QListWidgetItem *> selectItems = d->mListThemes->selectedItems();
     if (!selectItems.isEmpty()) {
         QString msg;
         const int selectedThemeCount(selectItems.count());
@@ -118,7 +118,7 @@ void ManageThemes::slotDeleteTheme()
             msg = i18n("Do you want to remove %1 selected themes?", selectedThemeCount);
         }
         if (KMessageBox::questionYesNo(this, msg, i18n("Remove theme")) == KMessageBox::Yes) {
-            Q_FOREACH (QListWidgetItem *item, selectItems) {
+            for (QListWidgetItem *item : selectItems) {
                 if (QDir((d->mLocalDirectory + QDir::separator() + item->text())).removeRecursively()) {
                     delete item;
                 } else {
