@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -29,7 +29,7 @@ class GRANTLEETHEMEEDITOR_EXPORT NewThemeDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit NewThemeDialog(QWidget *parent = Q_NULLPTR);
+    explicit NewThemeDialog(QWidget *parent = nullptr);
     ~NewThemeDialog();
 
     QString themeName() const;
